@@ -1,8 +1,14 @@
 import typer
 
-from . import _print_unused_id_ranges, _print_used_id_ranges, _scan_groups_and_users
+from . import (
+    _print_unused_id_ranges,
+    _print_used_id_ranges,
+    _scan_groups_and_users,
+    report,
+)
 
 app = typer.Typer(help="DICE admin commands")
+app.add_typer(report.app, name="report")
 
 
 @app.command()
