@@ -1,17 +1,19 @@
 from itertools import groupby
+from pathlib import Path
 from typing import List
 
+from dice_lib.ranges import as_range, groupby_range
+
 from .._io import read_ints_from_csv
 from ..logger import admin_logger
-from ..utils import as_range, groupby_range
 
 
 def _read_userids(filename: str) -> List[int]:
-    return read_ints_from_csv(filename, "uid")
+    return read_ints_from_csv(Path(filename), "uid")
 
 
 def _read_groupids(filename: str) -> List[int]:
-    return read_ints_from_csv(filename, "gid")
+    return read_ints_from_csv(Path(filename), "gid")
 
 
 def main(users_file: str, group_file: str) -> None:
