@@ -1,8 +1,10 @@
+from pathlib import Path
 from typing import Any, Dict, List
 
+from dice_lib.host import current_fqdn
+
 from .._io import write_list_data_as_dict_to_csv
 from ..logger import admin_logger
-from ..utils import current_fqdn
 
 
 def _read_groups() -> List[Dict[str, str]]:
@@ -29,13 +31,13 @@ def _write_users_to_csv(
     users: List[Dict[str, Any]],
     output_file: str = "/tmp/users.csv",
 ) -> None:
-    write_list_data_as_dict_to_csv(users, output_file, ["name", "uid", "gid"])
+    write_list_data_as_dict_to_csv(users, ["name", "uid", "gid"], Path(output_file))
 
 
 def _write_groups_to_csv(
     groups: List[Dict[str, Any]], output_file: str = "/tmp/groups.csv"
 ) -> None:
-    write_list_data_as_dict_to_csv(groups, output_file, ["name", "gid"])
+    write_list_data_as_dict_to_csv(groups, ["name", "gid"], Path(output_file))
 
 
 def main() -> None:
